pub trait ExWidget {
// Required method
fn ui_ex(self, ex_ui: &mut ExUi<'_, '_>) -> Response;
}Expand description
Similar to egui::Widget, but for use with ExUi
Anything implementing Widget can be added to a ExUi with ExUi::add, but this trait is if you prefer to use widget.ui_ex(ui).
This trait is implemented for all types that implement egui::Widget